
\NeedsTeXFormat{LaTeX2e}[2001/06/01]
\ProvidesClass{hufsthesis09}[2009/12/05 v0.21]

\RequirePackage{ifxetex}
\RequireXeTeX

\RequirePackage{calc,ifthen}
\newboolean{@crop}
\DeclareOption{crop}{\setboolean{@crop}{true}}
\newboolean{@external}
\DeclareOption{external}{\setboolean{@external}{true}}
\newboolean{@otf}
\DeclareOption{otf}{\setboolean{@otf}{true}}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\ExecuteOptions{a4paper,11pt,oneside}
\ProcessOptions

\LoadClass{report}
\RequirePackage{amsmath,amsthm,amsfonts,amssymb}
\RequirePackage{xetexko}
\input{konames-utf}

\def\Location{}
\ifthenelse{\boolean{@external}}{\def\Location{ExternalLocation}}{}
\def\OTF{}
\ifthenelse{\boolean{@otf}}{\def\OTF{OTF}}{}
\setmainhangulfont[BoldFont={*ExtraBold}]{NanumMyeongjo\OTF}
\setsanshangulfont[BoldFont={*ExtraBold}]{NanumGothic\OTF}
\setmainhanjafont[\Location]{UnBatang}
\setsanshanjafont[\Location]{UnDotum}

\RequirePackage[hangul]{dhucs-setspace}
\setstretch{1.5}

\RequirePackage{geometry}
\geometry{%
  paperwidth=190truemm,
  paperheight=260truemm,
  left=37truemm,
  right=37truemm,
  top=30truemm,
  bottom=13truemm
}
\ifthenelse{\boolean{@crop}}{\RequirePackage[cam,a4]{crop}}{}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewenvironment{thebibliography}[1]
     {\chapter*{\bibname}%
      \@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m%
      \setstretch{1.333}}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Cover Data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\Degree}[1]{\newcommand{\degr}{#1}}
\newcommand{\DegreeAsChi}[1]{\newcommand{\hjdegr}{#1}}
\newcommand{\Title}[1]{\newcommand{\htitle}{#1}}
\newcommand{\TitleAsEng}[1]{\newcommand{\etitle}{#1}}
\newcommand{\Subtitle}[1]{\newcommand{\stitle}{#1}}
\newcommand{\Author}[1]{\newcommand{\hauthor}{#1}}
\newcommand{\AuthorAsChi}[1]{\newcommand{\hjauthor}{#1}}
\newcommand{\AuthorAsEng}[1]{\newcommand{\eauthor}{#1}}
\newcommand{\Major}[1]{\newcommand{\majorname}{#1}}
\newcommand{\MajorAsEng}[1]{\newcommand{\majorename}{#1}}
\newcommand{\School}[1]{\newcommand{\schoolname}{#1}}
\newcommand{\SchoolAsEng}[1]{\newcommand{\schoolename}{#1}}
\newcommand{\PublDate}[3]{%
  \newcommand{\cyear}{#1}\newcommand{\cmonth}{#2}\newcommand{\cdate}{#3}}
\newcommand{\RefereeDate}[3]{%
  \newcommand{\thesisy}{#1}\newcommand{\thesism}{#2}\newcommand{\thesisd}{#3}}
\newcommand{\Advisor}[1]{\newcommand{\hjad}{#1}}
\newcommand{\AdvisorAsEng}[1]{\newcommand{\ejad}{#1}}
\newcommand{\Keywords}[1]{\newcommand{\keywords}{#1}}

\newcounter{NOR}\setcounter{NOR}{\@ne}
\newcommand{\NumberOfReferees}[1]{\setcounter{NOR}{#1}}

\newcommand{\univname}{영남대학교}
\newcommand{\univename}{Yeungnam University}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Chapter Design
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\contentsname}{목차}
\renewcommand{\listfigurename}{그림~목차}
\renewcommand{\listtablename}{표~목차}
%\renewcommand{\figurename}{그림}
%\renewcommand{\tablename}{표}
%\renewcommand{\chaptername}{장}
%\renewcommand{\bibname}{참고 문헌}
%%%%%%%머릿말크기%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\@makechapterhead}[1]{%
  \begin{center}
    \normalfont
    \ifnum \c@secnumdepth >\m@ne
      {\LARGE\bfseries \@chapapp\space \thechapter}\par\nobreak\vspace*{8mm}
    \fi
    \interlinepenalty\@M
    {\Huge\bfseries #1}\par\nobreak
  \end{center}
  \vspace*{10mm}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\@makeschapterhead}[1]{%
  \vspace*{-15mm}%
  \begin{center}
    \interlinepenalty\@M
    \normalfont\huge\bfseries #1\par\nobreak
  \end{center}
  \vspace*{8mm}
}
\newcommand{\@hufsschapterhead}[1]{%
  \newpage
  \addcontentsline{toc}{chapter}{#1}
  \@makeschapterhead{#1}
}
%%국문초록%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Abstract}{%
 \begin{center}
 \bf{
\vspace*{-9mm}
    {\fontsize{11}{10}\selectfont\makeonehalfsize{국문초록}\par}

\vspace*{10mm}
    {\fontsize{15}{15}\selectfont\let\\\ignorespaces\htitle} 
    %{\fontsize{14}{14}\selectfont\etitle}
    \ifx\stitle\@undefined\else
      %\\[1mm] {\fontsize{14}{14}\selectfont\stitle}
    \fi
  
  \vspace*{5.5mm}
  
  \setstretch{4}
   \hauthor \\ \univname\quad\schoolname \\ \majorname 전공\\ (지도교수 \quad\hjad)}
    
  \end{center}
  \vspace*{7mm}
}{\par\vfill}
%%영문초록%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{AbstractAsEng}{%

  \begin{center}
\bf{
\vspace*{-9mm}
    {\fontsize{12}{10}\selectfont\makeonehalfsize{M.A.Thesis}\par}
\vspace*{10mm}
    %{\fontsize{16}{16}\selectfont\let\\\ignorespaces\htitle} 
    {\fontsize{17}{17}\selectfont\etitle}
    \ifx\stitle\@undefined\else
     \\[3mm] {\fontsize{14}{14}\selectfont\stitle}
    \fi
  
  \vspace*{5.5mm}
  
    \setstretch{2}
    
    \large{  \eauthor \\ Department of   \majorename \\ \schoolename \\ \univename \\ (Advised by professor \ejad) \newline \null \newline Abstract}
   } 
  \end{center}
  \vspace*{5mm}
  \setstretch{1.25}
}{%\par\vfill\noindent{\bfseries Keywords:}\enspace\keywords
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Acknowledgement}{%
  \@hufsschapterhead{감사의 글}
}{\par\vfill}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Appendix}{%
  \@hufsschapterhead{부록}
}{\par\vfill}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Section Design
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\section}{%
  \bigskip
  \@startsection{section}{1}{\z@}%
                {-3.5ex \@plus -1ex \@minus -.2ex}{2.3ex \@plus.2ex}%
                {\normalfont\Large\bfseries}}
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Conver Design
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\makecover}{%
  \pagestyle{empty}
  \FrontPage\newpage
  \InnerPage\newpage
  \RefereePage\newpage
  \ApprovalPage\newpage
  \pagestyle{plain}
}
\newlength\templen
\newcommand{\makeonehalfsize}[1]{%
  \settowidth{\templen}{#1}{\hbadness=10000\makebox[1.3\templen][s]{#1}}%
}
%\raisebox{-120mm}[0pt][0pt]{\makebox[0pt]{\rule{10mm}{120mm}}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 표지
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\FrontPage}{%
  \begin{center}
  \bf{  \vspace*{-9mm}
    {\fontsize{12}{12}\selectfont\makeonehalfsize{\degr 학위논문}\par}
    
\vspace*{25mm}
    {\fontsize{21}{21}\selectfont\htitle\par}
\ifx\stitle\@undefined\else
    

\vspace*{20mm}
    {\fontsize{14}{14}\selectfont\univname\quad\schoolname\par}

    \vspace*{10mm}
    {\fontsize{14}{14}\selectfont\makeonehalfsize{\majorname 전공}\par}

    \vspace*{20mm}
    {\fontsize{14}{14}\selectfont\makeonehalfsize{\hauthor}\par}

\vspace*{56mm}
    {\fontsize{12}{12}\selectfont 지도교수\enspace\makeonehalfsize{\hjad}\par}
 
 \vspace*{21mm}
    {\fontsize{12}{12}\selectfont\cyear\@.\quad\cmonth\@.\par}

   \vspace*{-4mm}}
  \end{center}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 내표지
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\InnerPage}{%
  \begin{center}
  \bf{ \vspace*{-9mm}
    {\fontsize{12}{12}\selectfont\makeonehalfsize{\degr 학위논문}\par}
    
\vspace*{25mm}
    {\fontsize{21}{21}\selectfont\htitle\par}
\ifx\stitle\@undefined\else
    

\vspace*{20mm}
    {\fontsize{14}{14}\selectfont\univname\quad\schoolname\par}

    \vspace*{10mm}
    {\fontsize{14}{14}\selectfont\makeonehalfsize{\majorname 전공}\par}

    \vspace*{20mm}
    {\fontsize{14}{14}\selectfont\makeonehalfsize{\hauthor}\par}

\vspace*{56mm}
    {\fontsize{12}{12}\selectfont 지도교수\enspace\makeonehalfsize{\hjad}\par}
 
 \vspace*{21mm}
    {\fontsize{12}{12}\selectfont\cyear\@.\quad\cmonth\@.\par}

   \vspace*{-4mm}}
  \end{center}
}        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 심사청구서
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\RefereePage}{%
  \begin{center}
\bf{
\vspace*{-9mm}
    {\fontsize{12}{12}\selectfont\makeonehalfsize{\degr 학위논문}\par}
 
\vspace*{20mm}
    {\fontsize{21}{21}\selectfont\htitle\par}
    
\vspace*{20mm}
    {\fontsize{12}{12}\selectfont 지도교수\enspace\makeonehalfsize{\hjad}\par}
   
 \vspace*{40mm}
    {\fontsize{14}{14}\selectfont 이 논문을 석사학위 청구논문으로 제출함.\par}
   
 \vspace*{30mm}
    {\fontsize{14}{12}\selectfont\cyear\@.\quad\cmonth\@.\par}
   
 \vspace*{20mm}
    {\fontsize{14}{14}\selectfont\univname\enspace\schoolname\par}
    
\vspace*{5mm}
    {\fontsize{12}{12}\selectfont\makeonehalfsize{\majorname 전공}\par}
   
 \vspace*{5mm}
    {\fontsize{14}{14}\selectfont\makeonehalfsize{\hauthor}\par}
  
  \vspace*{-4mm}}
  \end{center}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 인준서
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\ApprovalPage}{%
  \begin{center}
   \bf{
 \vspace*{-1mm}
    {\fontsize{21}{21}\selectfont
       \hauthor의 석사학위 논문을 인준함.\par}
    
    \vspace*{25mm}
    {\fontsize{14}{20}\selectfont\settowidth{\templen}{\LARGE 심사위원}
      \def\eachreferee{{\hbadness=10000\makebox[1.1\templen][s]{심사위원}}   & \underline{\makebox[50mm][r]{(印)}} \\}
      
\begin{tabular}{ll}
      {\hbadness=10000\makebox[1.1\templen][s]{심사위원}} & \underline{\makebox[50mm][r]{(印)}} \\
      \@whilenum\value{NOR}>\@ne\do{%
        \eachreferee\addtocounter{NOR}{\m@ne}}
      \end{tabular}\par}
    
\vspace*{90mm}
    {\fontsize{16}{16}\selectfont\cyear\@.\quad\cmonth\@.\par}  
\vspace*{20mm}
    {\fontsize{18}{18}\selectfont\univname\enspace\schoolname\par}
    \vspace*{-4mm}}
  \end{center}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\endinput
